/****************************************************************************
 *
 * $Id:
 *
 * Copyright (C) 1998-2006 Lasmea. All rights reserved.
 *
 * This software was developed at:
 * Institut Pascal- UMR 6602
 * 63 175 Aubière Cedex
 * http://ip.univ-bpclermont.fr
 *
 * This file may be distributed under the terms of the Q Public License
 * as defined by Trolltech AS of Norway and appearing in the file
 * LICENSE included in the packaging of this file.
 *
 * Licensees holding valid IPDS Professional Edition licenses may
 * use this file in accordance with the IPDS Commercial License
 * Agreement provided with the Software.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Contact . if any conditions of this licensing are
 * not clear to you.
 *
 *
 * Author: Jonathan Courbon - Hemanth Korrapati -
 *
 *****************************************************************************/


#include <iostream>
#include <sstream>
#include <vector>
#include <string>

#include "containers.h"
#include "config.h"


void usage()
{
    std::cout << "============================" << std::endl;
    std::cout << "  Data synchronisation" << std::endl;
    std::cout << "============================" << std::endl;
    std::cout << "Usage: ./DataSynchronisation sequencePath sensor1Alias sensor2Alias" << std::endl;
}



int main(int argc, char* argv[])
{

    setlocale (LC_ALL,"C");

    if(argc==4)
    {
      std::string sequencePath(argv[1]);
      std::string sensor1Alias(argv[2]);
      std::string sensor2Alias(argv[3]);
      
      ConfigTable ctable;
      std::stringstream msg;
      msg << CONFIGFOLDERPATH << "/config_table";
      ctable.readTable(msg.str());
      
      // read data for sensor 1
      std::vector<Unit> data1;
      std::string timestamps_file_name1=ctable.table[sensor1Alias].folderName+ctable.table[sensor1Alias].suffix;
      std::string sensor_data_folder1=sequencePath+"/"+ctable.table[sensor1Alias].folderName+"/";    
      getReadings(ctable.table[sensor1Alias].sensorName, sensor_data_folder1, timestamps_file_name1, ctable.table[sensor1Alias].tfm, data1, TimestampInterval());
      
      // read data for sensor 2
      std::vector<Unit> data2;
      std::string timestamps_file_name2=ctable.table[sensor2Alias].folderName+ctable.table[sensor2Alias].suffix;
      std::string sensor_data_folder2=sequencePath+"/"+ctable.table[sensor2Alias].folderName+"/";    
      getReadings(ctable.table[sensor2Alias].sensorName, sensor_data_folder2, timestamps_file_name2, ctable.table[sensor2Alias].tfm, data2, TimestampInterval());
      
      
      
      std::cout << "================" << std::endl;
      std::cout << "There are " << data1.size() << " data for the sensor " << sensor1Alias << " and " << data2.size() << " data for sensor " << sensor2Alias << " in the sequence stored in " << sequencePath << std::endl;
      std::cout << "================" << std::endl;
      
      // synchronise
      std::vector<int> synchroMap;
      synchronizePair(data1, data2, synchroMap);
      
      unsigned int i=0;
      while(i<synchroMap.size())
      {
	  if(synchroMap[i]!=-1) // synchro OK
	  {
	      std::cout << "The " << i << "th data of sensor " << sensor1Alias << " is acquired approximately at the same time as the " << synchroMap[i] << "th data of sensor " << sensor2Alias << std::endl;
	  }
      }
      
    }
    else
    {
      usage();
    }


  return 0;


}





