/****************************************************************************
 *
 * $Id:
 *
 * Copyright (C) 1998-2006 Lasmea. All rights reserved.
 *
 * This software was developed at:
 * Institut Pascal- UMR 6602
 * 63 175 Aubière Cedex
 * http://ip.univ-bpclermont.fr
 *
 * This file may be distributed under the terms of the Q Public License
 * as defined by Trolltech AS of Norway and appearing in the file
 * LICENSE included in the packaging of this file.
 *
 * Licensees holding valid IPDS Professional Edition licenses may
 * use this file in accordance with the IPDS Commercial License
 * Agreement provided with the Software.
 *
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * Contact . if any conditions of this licensing are
 * not clear to you.
 *
 *
 * Author: Jonathan Courbon - Hemanth Korrapati -
 *
 *****************************************************************************/


#include <iostream>
#include <sstream>
#include <vector>

#include <stdio.h>
#include <string.h>

#include "containers.h"
#include "config.h"
#include "sensor_data.h"



void usage()
{
    std::cout << "============================" << std::endl;
    std::cout << "  Data synchronisation" << std::endl;
    std::cout << "============================" << std::endl;
    std::cout << "Usage: ./DataSynchronisation sequencePath visualSensorAlias gpsSensorAlias" << std::endl;
}



int main(int argc, char* argv[])
{

    setlocale (LC_ALL,"C");

    if(argc==4)
    {
      std::string sequencePath(argv[1]);
      std::string visualSensor(argv[2]);
      std::string gpsSensor(argv[3]);
      
      if( (strcmp(visualSensor.c_str(),"f-l-cam")==0 || strcmp(visualSensor.c_str(),"f-m-cam")==0 || strcmp(visualSensor.c_str(),"f-r-cam")==0 || strcmp(visualSensor.c_str(),"b-cam") || strcmp(visualSensor.c_str(),"webcam")==0 ) && (strcmp(gpsSensor.c_str(),"r-gps")==0 || strcmp(gpsSensor.c_str(),"l-gps")==0) )
      {
      
	ConfigTable ctable;
	std::stringstream msg;
	msg << CONFIGFOLDERPATH << "/config_table";
	ctable.readTable(msg.str());
	
	// read data for sensor 1
	std::vector<Unit> data1;
	std::string timestamps_file_name1=ctable.table[visualSensor].folderName+ctable.table[visualSensor].suffix;
	std::string sensor_data_folder1=sequencePath+"/"+ctable.table[visualSensor].folderName+"/";    
	getReadings(ctable.table[visualSensor].sensorName, sensor_data_folder1, timestamps_file_name1, ctable.table[visualSensor].tfm, data1, TimestampInterval());
	
	// read data for sensor 2
	std::vector<Unit> data2;
	std::string timestamps_file_name2=ctable.table[gpsSensor].folderName+ctable.table[gpsSensor].suffix;
	std::string sensor_data_folder2=sequencePath+"/"+ctable.table[gpsSensor].folderName+"/";    
	getReadings(ctable.table[gpsSensor].sensorName, sensor_data_folder2, timestamps_file_name2, ctable.table[gpsSensor].tfm, data2, TimestampInterval());
	
	
	
	std::cout << "================" << std::endl;
	std::cout << "There are " << data1.size() << " data for the sensor " << visualSensor << " and " << data2.size() << " data for sensor " << gpsSensor << " in the sequence stored in " << sequencePath << std::endl;
	std::cout << "================" << std::endl;
	
	// synchronise
	std::vector<int> synchroMap;
	synchronizePair(data1, data2, synchroMap);
	
	std::cout << "The georeferenced positions (expressed in meters) of the images are the following: " << std::endl;
	std::string fullpath;
	unsigned int i=0;
	while(i<synchroMap.size())
	{
	    if(synchroMap[i]!=-1) // synchro OK
	    {
		ctable.getSensorFilePathFromIndex(visualSensor,fullpath,data1[i].index);
		gps_data mygpsdata(data2[synchroMap[i]].reading);
		std::cout << fullpath << " at position : ( " << mygpsdata.lat_l2e << " ; " << mygpsdata.lng_l2e << " ) ; h= " << mygpsdata.alt_l2e << " m  and UTC time: " << data1[i].timestamp << std::endl;
	    }
	}
      }
      else
      {
	usage();
      }
      
    }
    else
    {
      usage();
    }


  return 0;


}





